flutter_meta_wearables_dat library

Classes

CapturedFrame
A single video frame captured from an active stream session's Flutter texture.
CapturedPhoto
Represents a photo captured from a Meta Wearables device.
MetaWearablesDat
The main class for the Meta Wearables DAT.
StreamSessionError
Represents an error that occurred during a stream session.

Enums

FrameFormat
Supported pixel formats for captured stream frames.
PhotoCaptureFormat
Supported photo capture formats.
RegistrationState
Represents the current state of user registration with the Meta Wearables platform.
StreamQuality
Supported streaming quality levels.
StreamSessionState
Represents the current state of a stream session.
VideoCodec
Video codec to use for streaming.

Exceptions / Errors

CameraPermissionException
Exception thrown when a camera permission request fails.