channelId property
Unique notification channel id. Reuse the same value across calls to avoid re-creating the channel.
Implementation
final String channelId;
Unique notification channel id. Reuse the same value across calls to avoid re-creating the channel.
final String channelId;