CapturedPhoto class

Represents a photo captured from a Meta Wearables device.

Constructors

CapturedPhoto({required Uint8List bytes, required String format})
const

Properties

bytes Uint8List
The bytes of the captured photo.
final
fileExtension String
no setter
format String
The format of the captured photo.
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited