MetaWearablesDatPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • MetaWearablesDatPlatform
Implementers

Constructors

MetaWearablesDatPlatform()
Constructs a MetaWearablesDatPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activeDeviceStream() → Stream<bool>
capturePhoto(String? deviceId, {PhotoCaptureFormat format = PhotoCaptureFormat.jpeg}) → Future<CapturedPhoto>
deviceStateStream() → Stream<DeviceState>
disableBackgroundStreaming() → Future<void>
disconnect() → Future<bool>
enableBackgroundStreaming({BackgroundNotification? androidNotification}) → Future<void>
getCameraPermissionStatus() → Future<bool>
getDevices() → Future<List<WearableDevice>>
getRegistrationState() → Future<RegistrationState>
handleUrl(String url) → Future<bool>
isBackgroundStreamingEnabled() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDATGlassesAppUpdate() → Future<bool>
registrationStateStream() → Stream<RegistrationState>
requestAndroidPermissions() → Future<bool>
requestCameraPermission() → Future<bool>
restartActiveDeviceMonitoring() → Future<bool>
startRegistration() → Future<bool>
startStreamSession(String? deviceId, {StreamFrameRate frameRate = StreamFrameRate.fps30, StreamQuality streamQuality = StreamQuality.high, VideoCodec videoCodec = VideoCodec.raw}) → Future<int>
Starts a stream session. Returns a texture ID (int) for rendering via the Flutter Texture widget (zero-copy path).
stopStreamSession(String? deviceId) → Future<bool>
streamSessionErrorStream() → Stream<StreamSessionError>
streamSessionStateStream() → Stream<StreamSessionState>
toString() → String
A string representation of this object.
inherited
videoFramesStream({double? maxFramesPerSecond}) → Stream<VideoFrame>
videoStreamSizeStream() → Stream<VideoStreamSize>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ MetaWearablesDatPlatform
The default instance of MetaWearablesDatPlatform to use.
getter/setter pair