MethodChannelMetaWearablesDat class

An implementation of MetaWearablesDatPlatform that uses method channels.

Inheritance

Properties

activeDeviceEventChannel EventChannel
The event channel used to receive active device availability updates.
final
eventChannel EventChannel
The event channel used to receive registration state updates.
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamSessionErrorEventChannel EventChannel
The event channel used to receive stream session errors.
final
streamSessionStateEventChannel EventChannel
The event channel used to receive stream session state updates.
final
videoFramesEventChannel EventChannel
The event channel used to receive per-frame video samples when background streaming is enabled.
final
videoStreamSizeEventChannel EventChannel
The event channel used to receive video frame dimensions for the active stream session.
final

Methods

activeDeviceStream() Stream<bool>
override
capturePhoto(String? deviceUUID, {PhotoCaptureFormat format = PhotoCaptureFormat.jpeg}) Future<CapturedPhoto>
override
disableBackgroundStreaming() Future<void>
override
disconnect() Future<bool>
override
enableBackgroundStreaming({BackgroundNotification? androidNotification}) Future<void>
override
getCameraPermissionStatus() Future<bool>
override
getRegistrationState() Future<RegistrationState>
override
handleUrl(String url) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registrationStateStream() Stream<RegistrationState>
override
requestAndroidPermissions() Future<bool>
override
requestCameraPermission() Future<bool>
override
restartActiveDeviceMonitoring() Future<bool>
override
startRegistration() Future<bool>
override
startStreamSession(String? deviceUUID, {double fps = 30.0, StreamQuality streamQuality = StreamQuality.high, VideoCodec videoCodec = VideoCodec.raw}) Future<int>
Starts a stream session. Returns a texture ID (int) for rendering via the Flutter Texture widget (zero-copy path).
override
stopStreamSession(String? deviceUUID) Future<bool>
override
streamSessionErrorStream() Stream<StreamSessionError>
override
streamSessionStateStream() Stream<StreamSessionState>
override
toString() String
A string representation of this object.
inherited
videoFramesStream() Stream<VideoFrame>
override
videoStreamSizeStream() Stream<VideoStreamSize>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited