MetaWearablesDatPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- MetaWearablesDatPlatform
- Implementers
Constructors
- MetaWearablesDatPlatform()
- Constructs a MetaWearablesDatPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activeDeviceStream(
) → Stream< bool> -
capturePhoto(
String? deviceUUID, {PhotoCaptureFormat format = PhotoCaptureFormat.jpeg}) → Future< CapturedPhoto> -
disableBackgroundStreaming(
) → Future< void> -
disconnect(
) → Future< bool> -
enableBackgroundStreaming(
{BackgroundNotification? androidNotification}) → Future< void> -
getCameraPermissionStatus(
) → Future< bool> -
getRegistrationState(
) → Future< RegistrationState> -
handleUrl(
String url) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registrationStateStream(
) → Stream< RegistrationState> -
requestAndroidPermissions(
) → Future< bool> -
requestCameraPermission(
) → Future< bool> -
restartActiveDeviceMonitoring(
) → Future< bool> -
startRegistration(
) → Future< bool> -
startStreamSession(
String? deviceUUID, {double fps = 30.0, StreamQuality streamQuality = StreamQuality.high, VideoCodec videoCodec = VideoCodec.raw}) → Future< int> -
Starts a stream session. Returns a texture ID (int) for rendering
via the Flutter
Texturewidget (zero-copy path). -
stopStreamSession(
String? deviceUUID) → Future< bool> -
streamSessionErrorStream(
) → Stream< StreamSessionError> -
streamSessionStateStream(
) → Stream< StreamSessionState> -
toString(
) → String -
A string representation of this object.
inherited
-
videoFramesStream(
) → Stream< VideoFrame> -
videoStreamSizeStream(
) → Stream< VideoStreamSize>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ MetaWearablesDatPlatform
-
The default instance of MetaWearablesDatPlatform to use.
getter/setter pair